@@ -20,4 +20,10 @@ INSTALLED_APPS = [
     "django_huey"
 ]
 
-HUEYS = {}
\ No newline at end of file
+DJANGO_HUEY = {
+    'queues': {}
+}
+HUEY = {
+    'name': 'test',
+    'immediate': True,
+}
